@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico. 
-   Copyright (C) 1998-2016 Sergey Poznyakoff
+   Copyright (C) 1998-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ dico_stream_t debug_stream;
 
 
 void
-fixup_url()
+fixup_url(void)
 {
     xdico_assign_string(&dico_url.proto, "dict");
     if (!dico_url.host)
