@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico. 
-   Copyright (C) 1998-2016 Sergey Poznyakoff
+   Copyright (C) 1998-2018 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 static char *pager;
 
 static char *
-get_pager_name()
+get_pager_name(void)
 {
     if (pager) {
 	if (strcmp(pager, "-") == 0)
@@ -46,7 +46,7 @@ ds_pager(int argc, char **argv)
 
 
 dico_stream_t
-create_output_stream()
+create_output_stream(void)
 {
     return dico_fd_stream_create(fileno(stdout), DICO_STREAM_WRITE, 1);
 }
