@@ -1748,77 +1748,88 @@ urf8_symcasecmp(char *a, char *b)
 	return 1;
     return 0;
 }
-
+
 int
-utf8_strcasecmp(char *a, char *b)
+utf8_compare(char const *a, char const *b,
+	     int ci, size_t maxlen, int (*wcsel)(unsigned))
 {
     int alen, blen;
+    size_t an = 0, bn = 0;
+    unsigned wa, wb;
 
-    for (; *a; a += alen, b += blen) {
-	unsigned wa, wb;
-
-	if (*b == 0)
-	    return 1;
-
-	alen = utf8_char_width(a);
-	if (alen == 0)
-	    return -1;
-	utf8_mbtowc(&wa, a, alen);
-	blen = utf8_char_width(b);
-	if (blen == 0)
-	    return 1;
-	utf8_mbtowc(&wb, b, blen);
-	wa = utf8_wc_toupper(wa);
-	wb = utf8_wc_toupper(wb);
-	if (wa < wb)
-	    return -1;
-	if (wa > wb)
-	    return 1;
-
-    }
-    if (*b)
-	return -1;
-    return 0;
-}
-
-int
-utf8_strncasecmp(char *a, char *b, size_t maxlen)
-{
-    int alen, blen;
-    unsigned asz = 0, bsz = 0;
-
-    while (asz < maxlen) {
-	unsigned wa, wb;
-
+    while (1) {
+	if (maxlen != 0 && an == maxlen)
+	    return 0;
 	if (*a == 0)
-	    return (*b == 0) ? 0 : -1;
-
-	if (*b == 0)
-	    return 1;
-
+	    break;
+	
 	alen = utf8_char_width(a);
 	if (alen == 0)
 	    return -1;
+	
 	utf8_mbtowc(&wa, a, alen);
+	a += alen;
+	an++;
+
+	if (!wcsel || wcsel(wa)) {
+	    if (*b == 0)
+		return 1;
+	    while (*b) {
+		if (maxlen != 0 && bn == maxlen)
+		    return 0;
+		blen = utf8_char_width(b);
+		if (blen == 0)
+		    return 1;
+		utf8_mbtowc(&wb, b, blen);
+		b += blen;
+		bn++;
+		
+		if (!wcsel || wcsel(wb)) {
+		    if (ci == case_insensitive) {
+			wa = utf8_wc_toupper(wa);
+			wb = utf8_wc_toupper(wb);
+		    }
+		    if (wa < wb)
+			return -1;
+		    if (wa > wb)
+			return 1;
+		    break;
+		}
+	    }
+	}
+    }
+
+    while (*b) {
 	blen = utf8_char_width(b);
 	if (blen == 0)
 	    return 1;
 	utf8_mbtowc(&wb, b, blen);
-	wa = utf8_wc_toupper(wa);
-	wb = utf8_wc_toupper(wb);
-	if (wa < wb)
-	    return -1;
-	if (wa > wb)
-	    return 1;
-	a += alen;
 	b += blen;
-	asz ++;
-	bsz ++;
+	if (!wcsel || wcsel(wb))
+	    return -1;
     }
+    
     return 0;
 }
 
+int
+utf8_strcmp(char const *a, char const *b)
+{
+    return utf8_compare(a, b, case_sensitive, 0, NULL);
+}
 
+int
+utf8_strcasecmp(char const *a, char const *b)
+{
+    return utf8_compare(a, b, case_insensitive, 0, NULL);
+}
+
+int
+utf8_strncasecmp(char const *a, char const *b, size_t maxlen)
+{
+    return utf8_compare(a, b, case_insensitive, maxlen, NULL);
+}
+
 unsigned
 utf8_wc_toupper(unsigned wc)
 {
@@ -2274,3 +2285,29 @@ utf8_quote(const char *str, char **sptr)
     }
     return rc;
 }
+
+int
+utf8_table_check(unsigned wc,
+		 unsigned const *start, int const *count, size_t size)
+{
+    const unsigned *l = start;
+    const unsigned *r = start + size;
+    const unsigned *s = NULL;
+
+    if (wc == 0)
+	return 0;
+
+    while (l < r) {
+	s = l + ((r - l) >> 1);
+
+	if (*s <= wc) {
+	    l = s + 1;
+	} else {
+	    r = s;
+	}
+    }
+    
+    --l;
+    
+    return (wc < l[0] + count[l - start]);
+}
