@@ -214,7 +214,6 @@ _guile_dico_key_free(SCM message_smob)
 {
     struct dico_key *kp = (struct dico_key *) SCM_CDR (message_smob);
     dico_key_deinit(kp);
-    free(kp);
     return 0;
 }
 
@@ -286,9 +285,8 @@ _make_strategy(const dico_strategy_t strat)
 static size_t
 _guile_strategy_free(SCM message_smob)
 {
-    struct _guile_strategy *sp =
-	(struct _guile_strategy *) SCM_CDR (message_smob);
-    free(sp);
+    /* Nothing to free in struct _guile_strategy: the strat member is
+       constant */
     return 0;
 }
 
